@@ -9,7 +9,23 @@ config = Config.getConfig(parentKey='core', key='Logger')
 
 
 import logging
-logging.basicConfig(filename='hackingtools.log', filemode='a', format='%(asctime)s %(levelname)s-%(message)s', datefmt='%Y-%m-%d %H:%M:%S')
+
+# create logger with 'spam_application'
+logger = logging.getLogger('hackingtools')
+logger.setLevel(logging.DEBUG)
+# create file handler which logs even debug messages
+fh = logging.FileHandler('hackingtools.log')
+fh.setLevel(logging.DEBUG)
+# create console handler with a higher log level
+ch = logging.StreamHandler()
+ch.setLevel(logging.ERROR)
+# create formatter and add it to the handlers
+formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+fh.setFormatter(formatter)
+ch.setFormatter(formatter)
+# add the handlers to the logger
+logger.addHandler(fh)
+logger.addHandler(ch)
 
 __colorama.init()
 
@@ -129,13 +145,13 @@ def printMessage(message, description=None, debug_module=False, debug_core=False
         msg = '{methodCalledFrom} - {message}'.format(methodCalledFrom=methodCalledFrom, message=message)
 
     if is_error:
-        logging.critical(msg)
+        logger.critical(msg)
     if is_info:
-        logging.info(msg)
+        logger.info(msg)
     if is_success:
-        logging.debug(msg)
+        logger.debug(msg)
     if is_warn:
-        logging.warning(msg)
+        logger.warning(msg)
 
     if (color == __Fore.YELLOW or is_warn):
         msg = '{e} - {m}'.format(e=warn_flag, m=msg)
