@@ -12,10 +12,10 @@ output_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), 'output'))
 class StartModule():
 
 	def __init__(self):
-		pass
+		self._main_gui_func_ = 'get_pdf_exif'
 
 	def help(self):
-		Logger.printMessage(message=ht.getFunctionsNamesFromModule('ht_metadata'))
+		Logger.printMessage(message=ht.getFunctionsNamesFromModule('ht_metadata'), debug_module=True)
 
 	def get_image_exif(self, filename):
 		Logger.printMessage(message='{methodName}'.format(methodName='get_image_exif'), description=filename, debug_module=True)
